.. _api_ref:

.. currentmodule:: esda

API reference
=============

.. _adbscan_api:

A-DBSCAN
--------

.. autosummary::
   :toctree: generated/

    esda.adbscan.ADBSCAN

.. _correlogram_api:

Correlogram
-----------

.. autosummary::
   :toctree: generated/

    esda.correlogram

.. _gamma_api:

Gamma Statistic
---------------

.. autosummary::
   :toctree: generated/

    esda.Gamma


.. _geary_api:

Geary Statistics
----------------

.. autosummary::
   :toctree: generated/

    esda.Geary
    esda.Geary_Local
    esda.Geary_Local_MV


.. _getis_api:

Getis-Ord Statistics
--------------------

.. autosummary::
   :toctree: generated/

    esda.G
    esda.G_Local


.. _join_api:

Join Count Statistics
---------------------

.. autosummary::
   :toctree: generated/

    esda.Join_Counts

Join Count Local Statistics
---------------------------

.. autosummary::
   :toctree: generated/

    esda.Join_Counts_Local
    esda.Join_Counts_Local_BV
    esda.Join_Counts_Local_MV


LOSH Statistics
---------------

.. autosummary::
   :toctree: generated/

    esda.LOSH

Modifiable Areal Unit Tests
---------------------------

.. autosummary::
   :toctree: generated/

    esda.Smaup


Moran Statistics
----------------

.. autosummary::
   :toctree: generated/

    esda.Moran
    esda.Moran_BV
    esda.Moran_BV_matrix
    esda.Moran_Local
    esda.Moran_Local_BV
    esda.Moran_Rate
    esda.Moran_Local_Rate
    esda.plot_moran_facet
    esda.MoranLocalPartial
    esda.MoranLocalConditional


Shape Statistics
-----------------

.. autosummary::
    :toctree: generated/

    esda.shape.boundary_amplitude
    esda.shape.convex_hull_ratio
    esda.shape.diameter_ratio
    esda.shape.equivalent_rectangular_index
    esda.shape.form_factor
    esda.shape.isoareal_quotient
    esda.shape.isoperimetric_quotient
    esda.shape.length_width_diff
    esda.shape.mass_moment_of_inertia
    esda.shape.minimum_bounding_circle_ratio
    esda.shape.moa_ratio
    esda.shape.moment_of_inertia
    esda.shape.nmi
    esda.shape.radii_ratio
    esda.shape.rectangularity
    esda.shape.reflexive_angle_ratio
    esda.shape.second_areal_moment
    esda.shape.second_moment_of_area
    esda.shape.shape_index
    esda.shape.squareness


Silhouette Statistics
----------------------

.. autosummary::
   :toctree: generated/

    esda.boundary_silhouette
    esda.path_silhouette
    esda.silhouettes.nearest_label
    esda.silhouettes.silhouette_alist


Spatial Pearson Statistics
--------------------------

.. autosummary::
   :toctree: generated/

    esda.Spatial_Pearson
    esda.Spatial_Pearson_Local


Utility Functions
-----------------

.. autosummary::
   :toctree: generated/

    esda.fdr
